@@ -513,8 +513,9 @@ gnome_font_face_find_closest (const guchar *name)
 		guchar *locale, *p;
 		guchar c[128];
 		GPFontEntry *e;
-		locale = setlocale (LC_ALL, NULL);
-		if (!locale) locale = "C";
+		locale = g_strdup (setlocale (LC_ALL, NULL));
+		if (!locale)
+			locale = g_strdup ("C");
 		strncpy (c, locale, 127);
 		c[127] = '\0';
 		p = c;
@@ -530,6 +531,7 @@ gnome_font_face_find_closest (const guchar *name)
 			}
 			face = e->face;
 		}
+		g_free (locale);
 	}
 	if (!face && map->fonts) {
 		/* No face, no default, load whatever font is first */
@@ -821,7 +823,9 @@ gff_load_metrics (GnomeFontFace *face, gint glyph)
 
 	gi = face->glyphs + glyph;
 
-	FT_Load_Glyph (face->ft_face, glyph, FT_LOAD_NO_SCALE | FT_LOAD_NO_HINTING | FT_LOAD_NO_BITMAP);
+	FT_Load_Glyph (face->ft_face, glyph,
+		       FT_LOAD_NO_SCALE | FT_LOAD_NO_HINTING |
+		       FT_LOAD_NO_BITMAP | FT_LOAD_IGNORE_TRANSFORM);
 
         gi->bbox.x0 = -face->ft_face->glyph->metrics.horiBearingX * face->ft2ps;
 	gi->bbox.y1 = face->ft_face->glyph->metrics.horiBearingY * face->ft2ps;
@@ -843,7 +847,9 @@ gff_load_outline (GnomeFontFace *face, gint glyph)
 	g_assert (face->ft_face);
 	g_assert (!face->glyphs[glyph].bpath);
 
-	FT_Load_Glyph (face->ft_face, glyph, FT_LOAD_NO_SCALE | FT_LOAD_NO_HINTING | FT_LOAD_NO_BITMAP);
+	FT_Load_Glyph (face->ft_face, glyph,
+		       FT_LOAD_NO_SCALE | FT_LOAD_NO_HINTING |
+		       FT_LOAD_NO_BITMAP | FT_LOAD_IGNORE_TRANSFORM);
 
 	a[0] = a[3] = face->ft2ps;
 	a[1] = a[2] = a[4] = a[5] = 0.0;
@@ -1189,16 +1195,8 @@ gff_pso_ensure_buffer_t1 (GFPSObject *pso)
 			status = FT_Get_Glyph_Name (pso->face->ft_face, g, c, 256);
 			if (status != FT_Err_Ok) {
 				g_warning ("file %s: line %d: Glyph %d has no name in %s", __FILE__, __LINE__, g, t1->pfb.name);
-#if 0
-				gff_pso_ensure_buffer_empty (pso);
-				return;
-#else
 				g_snprintf (c, 256, ".notdef");
-#endif
 			}
-#ifdef __GNUC__
-#warning Should this be g or glyph? See bug #80415
-#endif
 			gf_pso_sprintf (pso, ((glyph & 0xf) == 0xf) ? "/%s\n" : "/%s ", c);
 		}
 		gf_pso_sprintf (pso, "] def currentdict end\n");
@@ -1234,12 +1232,7 @@ gff_pso_ensure_buffer_t1 (GFPSObject *pso)
 				status = FT_Get_Glyph_Name (pso->face->ft_face, glyph, c, 256);
 				if (status != FT_Err_Ok) {
 					g_warning ("file %s: line %d: Glyph %d has no name in %s", __FILE__, __LINE__, glyph, t1->pfb.name);
-#if 0
-					gff_pso_ensure_buffer_empty (pso);
-					return;
-#else
 					g_snprintf (c, 256, ".notdef");
-#endif
 				}
 				gf_pso_sprintf (pso, ((j & 0xf) == 0xf) ? "/%s\n" : "/%s ", c);
 			}
@@ -1482,7 +1475,7 @@ gf_pso_sprintf (GFPSObject * pso, const gchar * format, ...)
 	gchar *text;
 	gint len;
 	
-	oldlocale = setlocale (LC_NUMERIC, NULL);
+	oldlocale = g_strdup (setlocale (LC_NUMERIC, NULL));
 	setlocale (LC_NUMERIC, "C");
 		
 	va_start (arguments, format);
@@ -1496,6 +1489,7 @@ gf_pso_sprintf (GFPSObject * pso, const gchar * format, ...)
 	g_free (text);
 
 	setlocale (LC_NUMERIC, oldlocale);
+	g_free (oldlocale);
 }
 
 static void
@@ -1512,483 +1506,147 @@ gf_pso_ensure_space (GFPSObject *pso, gint size)
 	}
 }
 
-
-#if 0
-/*
- * Create downloadable PS representation of given face
- */
-
-GFPSObject *
-gnome_font_face_create_ps_object (const GnomeFontFace * face)
+gdouble
+gnome_font_face_get_ascender (GnomeFontFace *face)
 {
-	GPFontEntry *entry;
+	g_return_val_if_fail (face != NULL, 1000.0);
+	g_return_val_if_fail (GNOME_IS_FONT_FACE (face), 1000.0);
 
-	g_return_val_if_fail (face != NULL, NULL);
-	g_return_val_if_fail (GNOME_IS_FONT_FACE (face), NULL);
+	if (!GFF_LOADED (face)) {
+		g_warning ("file %s: line %d: face %s: Cannot load face", __FILE__, __LINE__, face->entry->name);
+		return 1000.0;
+	}
+
+	return face->ft_face->ascender * face->ft2ps;
+}
+
+gdouble
+gnome_font_face_get_descender (GnomeFontFace * face)
+{
+	g_return_val_if_fail (face != NULL, 500.0);
+	g_return_val_if_fail (GNOME_IS_FONT_FACE (face), 500.0);
+
+	if (!GFF_LOADED (face)) {
+		g_warning ("file %s: line %d: face %s: Cannot load face", __FILE__, __LINE__, face->entry->name);
+		return 500.0;
+	}
+
+	/* fixme: I am clueless - FT spec says it is positive, but actually is not (Lauris) */
+	return face->ft_face->descender * face->ft2ps;
+}
+
+gdouble
+gnome_font_face_get_underline_position (GnomeFontFace * face)
+{
+	g_return_val_if_fail (face != NULL, -100.0);
+	g_return_val_if_fail (GNOME_IS_FONT_FACE (face), -100.0);
+
+	if (!GFF_LOADED (face)) {
+		g_warning ("file %s: line %d: face %s: Cannot load face", __FILE__, __LINE__, face->entry->name);
+		return -100.0;
+	}
+
+	return face->ft_face->underline_position * face->ft2ps;
+}
+
+gdouble
+gnome_font_face_get_underline_thickness (GnomeFontFace * face)
+{
+	g_return_val_if_fail (face != NULL, 10.0);
+	g_return_val_if_fail (GNOME_IS_FONT_FACE (face), 10.0);
+
+	if (!GFF_LOADED (face)) {
+		g_warning ("file %s: line %d: face %s: Cannot load face", __FILE__, __LINE__, face->entry->name);
+		return 10.0;
+	}
+
+	return face->ft_face->underline_thickness * face->ft2ps;
+}
+
+GnomeFontWeight
+gnome_font_face_get_weight_code (GnomeFontFace *face)
+{
+	GPFontEntry *e;
+
+	g_return_val_if_fail (face != NULL, GNOME_FONT_BOOK);
+	g_return_val_if_fail (GNOME_IS_FONT_FACE (face), GNOME_FONT_BOOK);
 
 	if (face->entry->type == GP_FONT_ENTRY_ALIAS) {
-		entry = ((GPFontEntryAlias *) face->entry)->ref;
+		e = ((GPFontEntryAlias *) face->entry)->ref;
 	} else {
-		entry = face->entry;
+		e = face->entry;
 	}
 
+	return e->Weight;
+
+	return GNOME_FONT_BOOK;
+}
+
+gboolean
+gnome_font_face_is_italic (GnomeFontFace * face)
+{
+	GPFontEntry *e;
+
+	g_return_val_if_fail (face != NULL, FALSE);
+	g_return_val_if_fail (GNOME_IS_FONT_FACE (face), FALSE);
+
+	if (face->entry->type == GP_FONT_ENTRY_ALIAS) {
+		e = ((GPFontEntryAlias *) face->entry)->ref;
+	} else {
+		e = face->entry;
+	}
+
+	return e->ItalicAngle;
+
+	return FALSE;
+}
+
+gboolean
+gnome_font_face_is_fixed_width (GnomeFontFace *face)
+{
+	g_return_val_if_fail (face != NULL, FALSE);
+	g_return_val_if_fail (GNOME_IS_FONT_FACE (face), FALSE);
+
+	if (!GFF_LOADED (face)) {
+		g_warning ("file %s: line %d: face %s: Cannot load face", __FILE__, __LINE__, face->entry->name);
+		return FALSE;
+	}
+
+	return FT_IS_FIXED_WIDTH (face->ft_face);
+}
+
+/*
+ * Returns PostScript name for glyph
+ */
+
+const guchar *
+gnome_font_face_get_glyph_ps_name (GnomeFontFace *face, gint glyph)
+{
+	static GHashTable *sgd = NULL;
+	FT_Error status;
+	gchar c[256], *name;
+
+	g_return_val_if_fail (face != NULL, ".notdef");
+	g_return_val_if_fail (GNOME_IS_FONT_FACE (face), ".notdef");
+
 	if (!GFF_LOADED (face)) {
 		g_warning ("file %s: line %d: Face %s: Cannot load face", __FILE__, __LINE__, face->entry->name);
-		/* fixme: create empty font */
-		return gff_empty_pso (face, entry);
+		return ".notdef";
 	}
 
-	switch (entry->type) {
-	case GP_FONT_ENTRY_TYPE1:
-		return gff_pso_from_type1 (face, entry);
-		break;
-	case GP_FONT_ENTRY_TRUETYPE:
-		return gff_pso_from_truetype (face, entry);
-		break;
-	default:
-		g_assert_not_reached ();
-		break;
+	if (!sgd) sgd = g_hash_table_new (g_str_hash, g_str_equal);
+
+	if ((glyph < 0) || (glyph >= face->num_glyphs)) glyph = 0;
+
+	status = FT_Get_Glyph_Name (face->ft_face, glyph, c, 256);
+	if (status != FT_Err_Ok) return ".notdef";
+
+	name = g_hash_table_lookup (sgd, c);
+	if (!name) {
+		name = g_strdup (c);
+		g_hash_table_insert (sgd, name, name);
 	}
 
-	return gff_empty_pso (face, entry);
+	return name;
 }
 
-#define INT32_LSB(q) ((q)[0] + ((q)[1] << 8) + ((q)[2] << 16) + ((q)[3] << 24))
-
-GFPSObject *
-gff_pso_from_type1 (const GnomeFontFace *face, GPFontEntry *entry)
-{
-	GPFontEntryT1 * t1;
-	GFPSObject * pso;
-	struct stat st;
-	guchar * fbuf;
-	gint fh;
-	const gchar * embeddedname;
-
-	t1 = (GPFontEntryT1 *) entry;
-
-	/* mmap file */
-	fh = open (t1->pfb.name, O_RDONLY);
-	if (fh < 0) {
-		g_warning ("file %s: line %d: Cannot open file %s", __FILE__, __LINE__, t1->pfb.name);
-		return gff_empty_pso (face, entry);
-	}
-	if (fstat (fh, &st) != 0) {
-		g_warning ("file %s: line %d: Cannot fstat file %s", __FILE__, __LINE__, t1->pfb.name);
-		return gff_empty_pso (face, entry);
-	}
-	fbuf = mmap (NULL, st.st_size, PROT_READ, MAP_SHARED, fh, 0);
-	close (fh);
-	if ((fbuf == NULL) || (fbuf == (guchar *) -1)) {
-		g_warning ("file %s: line %d: Cannot mmap file %s", __FILE__, __LINE__, t1->pfb.name);
-		return gff_empty_pso (face, entry);
-	}
-
-	pso = g_new (GFPSObject, 1);
-	pso->bufsize = st.st_size + 1024;
-	pso->length = 0;
-	pso->buf = g_new (guchar, pso->bufsize);
-	pso->encodedname = NULL;
-	pso->encodedbytes = 0;
-
-	if (*fbuf == 0x80) {
-		const char hextab[16] = "0123456789abcdef";
-		gint idx;
-		/* this is actually the same as a pfb to pfa converter
-		 * Reference: Adobe technical note 5040, "Supporting Downloadable PostScript
-		 * Language Fonts", page 9
-		 */
-		idx = 0;
-		while (idx < st.st_size) {
-			gint length, i;
-			if (fbuf[idx] != 0x80) {
-				g_warning ("Corrupted pfb file %s", t1->pfb.name);
-				munmap (fbuf, st.st_size);
-				g_free (pso->buf);
-				g_free (pso);
-				return gff_empty_pso (face, entry);
-			}
-			switch (fbuf[idx + 1]) {
-			case 1:
-				length = INT32_LSB (fbuf + idx + 2);
-				gf_pso_ensure_space (pso, length);
-				idx += 6;
-				memcpy (pso->buf + pso->length, fbuf + idx, length);
-				pso->length += length;
-				idx += length;
-				break;
-			case 2:
-				length = INT32_LSB (fbuf + idx + 2);
-				gf_pso_ensure_space (pso, length * 3);
-				idx += 6;
-				for (i = 0; i < length; i++) {
-					pso->buf[pso->length++] = hextab[fbuf[idx] >> 4];
-					pso->buf[pso->length++] = hextab[fbuf[idx] & 15];
-					idx += 1;
-					if ((i & 31) == 31 || i == length - 1) pso->buf[pso->length++] = '\n';
-				}
-				break;
-			case 3:
-				/* Finished */
-				gf_pso_ensure_space (pso, 1);
-				pso->buf[pso->length++] = '\n';
-				idx = st.st_size;
-				break;
-			default:
-				g_warning ("Corrupted pfb file %s", t1->pfb.name);
-				munmap (fbuf, st.st_size);
-				g_free (pso->buf);
-				g_free (pso);
-				return gff_empty_pso (face, entry);
-				break;
-			}
-		}
-	} else {
-		memcpy (pso->buf, fbuf, st.st_size);
-		pso->buf[st.st_size] = '\0';
-		pso->length = st.st_size;
-	}
-
-	munmap (fbuf, st.st_size);
-
-	embeddedname = entry->psname;
-	pso->encodedname = g_strdup_printf ("GnomeUni-%s", embeddedname);
-
-	if (face->num_glyphs < 256) {
-		gint glyph;
-		/* 8-bit vector */
-		pso->encodedbytes = 1;
-		gf_pso_sprintf (pso, "/%s findfont dup length dict begin\n", embeddedname);
-		gf_pso_sprintf (pso, "{1 index /FID ne {def} {pop pop} ifelse} forall\n");
-		gf_pso_sprintf (pso, "/Encoding [\n");
-		for (glyph = 0; glyph < 256; glyph++) {
-			guint g;
-			gchar c[256];
-			FT_Error status;
-			g = (glyph < face->num_glyphs) ? glyph : 0;
-			status = FT_Get_Glyph_Name (face->ft_face, glyph, c, 256);
-			if (status != FT_Err_Ok) {
-				g_warning ("Cannot get name of glyph %d", glyph);
-				g_free (pso->buf);
-				g_free (pso);
-				return gff_empty_pso (face, entry);
-			}
-			gf_pso_sprintf (pso, ((glyph & 0xf) == 0xf) ? "/%s\n" : "/%s ", c);
-		}
-		gf_pso_sprintf (pso, "] def currentdict end\n");
-		gf_pso_sprintf (pso, "/%s exch definefont pop\n", pso->encodedname);
-	} else {
-		gint nfonts, nglyphs, i, j;
-		/* 16-bit vector */
-		pso->encodedbytes = 2;
-		nglyphs = face->num_glyphs;
-		nfonts = (nglyphs + 255) >> 8;
-
-		gf_pso_sprintf (pso, "32 dict begin\n");
-		/* Common entries */
-		gf_pso_sprintf (pso, "/FontType 0 def\n");
-		gf_pso_sprintf (pso, "/FontMatrix [1 0 0 1 0 0] def\n");
-		gf_pso_sprintf (pso, "/FontName /%s-Glyph-Composite def\n", embeddedname);
-		gf_pso_sprintf (pso, "/LanguageLevel 2 def\n");
-
-		/* Type 0 entries */
-		gf_pso_sprintf (pso, "/FMapType 2 def\n");
-
-		/* Bitch 'o' bitches */
-		gf_pso_sprintf (pso, "/FDepVector [\n");
-		for (i = 0; i < nfonts; i++) {
-			gf_pso_sprintf (pso, "/%s findfont dup length dict begin\n", embeddedname);
-			gf_pso_sprintf (pso, "{1 index /FID ne {def} {pop pop} ifelse} forall\n");
-			gf_pso_sprintf (pso, "/Encoding [\n");
-			for (j = 0; j < 256; j++) {
-				gint glyph;
-				gchar c[256];
-				FT_Error status;
-				glyph = 256 * i + j;
-				if (glyph >= nglyphs) glyph = 0;
-				status = FT_Get_Glyph_Name (face->ft_face, glyph, c, 256);
-				if (status != FT_Err_Ok) {
-					g_warning ("Cannot get name of glyph %d", glyph);
-					g_free (pso->buf);
-					g_free (pso);
-					return gff_empty_pso (face, entry);
-				}
-				gf_pso_sprintf (pso, ((j & 0xf) == 0xf) ? "/%s\n" : "/%s ", c);
-			}
-			gf_pso_sprintf (pso, "] def\n");
-			gf_pso_sprintf (pso, "currentdict end /%s-Glyph-Page-%d exch definefont\n", embeddedname, i);
-		}
-		gf_pso_sprintf (pso, "] def\n");
-		gf_pso_sprintf (pso, "/Encoding [\n");
-		for (i = 0; i < 256; i++) {
-			gint fn;
-			fn = (i < nfonts) ? i : 0;
-			gf_pso_sprintf (pso, ((i & 0xf) == 0xf) ? "%d\n" : "%d  ", fn);
-		}
-		gf_pso_sprintf (pso, "] def\n");
-		gf_pso_sprintf (pso, "currentdict end\n");
-		gf_pso_sprintf (pso, "/%s exch definefont pop\n", pso->encodedname);
-	}
-
-	return pso;
-}
-
-/*
- * References:
- * Adobe Inc., PostScript Language Reference, 3rd edition, Addison Wesley 1999
- * Adobe Inc., The Type42 Font Format Specification, 1998 <http://partners.adobe.com/asn/developer/PDFS/TN/5012.Type42_Spec.pdf>
- */
-
-GFPSObject *
-gff_pso_from_truetype (const GnomeFontFace *face, GPFontEntry *entry)
-{
-	GPFontEntryTT * tt;
-	GFPSObject * pso;
-	struct stat st;
-	guchar * fbuf;
-	gint fh;
-	GSList *strings;
-	const gchar * embeddedname;
-	gdouble TTVersion, MfrRevision;
-	const ArtDRect *bbox;
-	gint i;
-
-	tt = (GPFontEntryTT *) entry;
-
-	/* mmap file */
-	fh = open (tt->ttf.name, O_RDONLY);
-	if (fh < 0) {
-		g_warning ("file %s: line %d: Cannot open file %s", __FILE__, __LINE__, filename);
-		return gff_empty_pso (face, entry);
-	}
-	if (fstat (fh, &st) != 0) {
-		g_warning ("file %s: line %d: Cannot fstat file %s", __FILE__, __LINE__, filename);
-		return gff_empty_pso (face, entry);
-	}
-	fbuf = mmap (NULL, st.st_size, PROT_READ, MAP_SHARED, fh, 0);
-	close (fh);
-	if ((fbuf == NULL) || (fbuf == (guchar *) -1)) {
-		g_warning ("file %s: line %d: Cannot mmap file %s", __FILE__, __LINE__, filename);
-		return gff_empty_pso (face, entry);
-	}
-
-	strings = gp_tt_split_file (fbuf, st.st_size);
-	if (strings == NULL) {
-		munmap (fbuf, st.st_size);
-		return gff_empty_pso (face, entry);
-	}
-
-	/* Create PSO */
-	pso = g_new (GFPSObject, 1);
-	pso->bufsize = st.st_size + 1024;
-	pso->length = 0;
-	pso->buf = g_new (guchar, pso->bufsize);
-	pso->encodedname = g_strdup_printf ("GnomeUni-%s", entry->psname);
-	pso->encodedbytes = 0;
-
-	embeddedname = entry->psname;
-
-	/* Download master font */
-	TTVersion = 1.0;
-	MfrRevision = 1.0;
-	gf_pso_sprintf (pso, "%%!PS-TrueTypeFont-%g-%g\n", TTVersion, MfrRevision);
-	gf_pso_sprintf (pso, "11 dict begin\n");
-	gf_pso_sprintf (pso, "/FontName /%s def\n", embeddedname);
-	gf_pso_sprintf (pso, "/Encoding 256 array\n");
-	gf_pso_sprintf (pso, "0 1 255 {1 index exch /.notdef put} for\n");
-	gf_pso_sprintf (pso, "readonly def\n");
-	gf_pso_sprintf (pso, "/PaintType 0 def\n");
-	gf_pso_sprintf (pso, "/FontMatrix [1 0 0 1 0 0] def\n");
-	/* fixme: */
-	bbox = gnome_font_face_get_stdbbox (face);
-	gf_pso_sprintf (pso, "/FontBBox [%g %g %g %g] def\n", bbox->x0, bbox->y0, bbox->x1, bbox->y1);
-	gf_pso_sprintf (pso, "/FontType 42 def\n");
-	/* fixme: XUID */
-	/* fixme: Be more intelligent */
-	gf_pso_sprintf (pso, "/sfnts [\n");
-	while (strings) {
-		guint start, next, size, i;
-		start = GPOINTER_TO_UINT (strings->data);
-		strings = g_slist_remove (strings, strings->data);
-		next = strings ? GPOINTER_TO_UINT (strings->data) : st.st_size;
-		size = next - start;
-		gf_pso_sprintf (pso, "<\n");
-		for (i = start; i < next; i+= 32) {
-			gint e, j;
-			e = MIN (i + 32, next);
-			for (j = i; j < e; j++) {
-				gf_pso_sprintf (pso, "%.2x", *(fbuf + j));
-			}
-			gf_pso_sprintf (pso, "\n");
-		}
-		gf_pso_sprintf (pso, strings ? ">\n" : "00>\n");
-	}
-	gf_pso_sprintf (pso, "] def\n");
-	/* fixme: Use CID or something */
-	gf_pso_sprintf (pso, "/CharStrings %d dict dup begin\n", face->num_glyphs);
-	gf_pso_sprintf (pso, "/.notdef 0 def\n");
-	for (i = 1; i < face->num_glyphs; i++) {
-		gf_pso_sprintf (pso, "/g%d %d def\n", i, i);
-	}
-	gf_pso_sprintf (pso, "end readonly def\n");
-	gf_pso_sprintf (pso, "FontName currentdict end definefont pop\n");
-
-	/* Unmap font file */
-	munmap (fbuf, st.st_size);
-
-	/*
-	 * We have font downloaded (hopefully)
-	 *
-	 * With CharStrings: .nodef g1 g2 g3 g4 g5...
-	 *
-	 * Now we have to build usable 2-byte encoded font from it
-	 *
-	 */
-
-	/* fixme: That is crap. We should use CID */
-	/* Bitch 'o' bitches (Lauris) ! */
-	if (face->num_glyphs < 256) {
-		gint glyph;
-		/* 8-bit vector */
-		pso->encodedbytes = 1;
-		gf_pso_sprintf (pso, "/%s findfont dup length dict begin\n", embeddedname);
-		gf_pso_sprintf (pso, "{1 index /FID ne {def} {pop pop} ifelse} forall\n");
-		gf_pso_sprintf (pso, "/Encoding [\n");
-		for (glyph = 0; glyph < 256; glyph++) {
-			guint g;
-			g = (glyph < face->num_glyphs) ? glyph : 0;
-			if (g == 0) {
-				gf_pso_sprintf (pso, ((glyph & 0xf) == 0xf) ? "/.notdef\n" : "/.notdef ", g);
-			} else {
-				gf_pso_sprintf (pso, ((glyph & 0xf) == 0xf) ? "/g%d\n" : "/g%d ", g);
-			}
-		}
-		gf_pso_sprintf (pso, "] def currentdict end\n");
-		gf_pso_sprintf (pso, "/%s exch definefont pop\n", pso->encodedname);
-	} else {
-		gint nfonts, nglyphs, i, j;
-		/* 16-bit vector */
-		pso->encodedbytes = 2;
-		nglyphs = face->num_glyphs;
-		nfonts = (nglyphs + 255) >> 8;
-
-		gf_pso_sprintf (pso, "32 dict begin\n");
-		/* Common entries */
-		gf_pso_sprintf (pso, "/FontType 0 def\n");
-		gf_pso_sprintf (pso, "/FontMatrix [1 0 0 1 0 0] def\n");
-		gf_pso_sprintf (pso, "/FontName /%s-Glyph-Composite def\n", embeddedname);
-		gf_pso_sprintf (pso, "/LanguageLevel 2 def\n");
-		/* Type 0 entries */
-		gf_pso_sprintf (pso, "/FMapType 2 def\n");
-		/* Bitch 'o' bitches */
-		gf_pso_sprintf (pso, "/FDepVector [\n");
-		for (i = 0; i < nfonts; i++) {
-			gf_pso_sprintf (pso, "/%s findfont dup length dict begin\n", embeddedname);
-			gf_pso_sprintf (pso, "{1 index /FID ne {def} {pop pop} ifelse} forall\n");
-			gf_pso_sprintf (pso, "/Encoding [\n");
-			for (j = 0; j < 256; j++) {
-				gint glyph;
-				glyph = 256 * i + j;
-				if (glyph >= nglyphs) glyph = 0;
-				if (glyph == 0) {
-					gf_pso_sprintf (pso, ((j & 0xf) == 0xf) ? "/.notdef\n" : "/.notdef ");
-				} else {
-					gf_pso_sprintf (pso, ((j & 0xf) == 0xf) ? "/g%d\n" : "/g%d ", glyph);
-				}
-			}
-			gf_pso_sprintf (pso, "] def\n");
-			gf_pso_sprintf (pso, "currentdict end /%s-Glyph-Page-%d exch definefont\n", embeddedname, i);
-		}
-		gf_pso_sprintf (pso, "] def\n");
-		gf_pso_sprintf (pso, "/Encoding [\n");
-		for (i = 0; i < 256; i++) {
-			gint fn;
-			fn = (i < nfonts) ? i : 0;
-			gf_pso_sprintf (pso, ((i & 0xf) == 0xf) ? "%d\n" : "%d  ", fn);
-		}
-		gf_pso_sprintf (pso, "] def\n");
-		gf_pso_sprintf (pso, "currentdict end\n");
-		gf_pso_sprintf (pso, "/%s exch definefont pop\n", pso->encodedname);
-	}
-
-	return pso;
-}
-
-GFPSObject *
-gff_empty_pso (const GnomeFontFace *face, GPFontEntry *entry)
-{
-	GFPSObject *pso;
-
-	/* Create PSO */
-	pso = g_new (GFPSObject, 1);
-	pso->bufsize = 1024;
-	pso->length = 0;
-	pso->buf = g_new (guchar, pso->bufsize);
-	pso->encodedname = g_strdup_printf ("GnomeEmpty-%s", entry->psname);
-	pso->encodedbytes = 1;
-
-	gf_pso_sprintf (pso, "%%Empty font generated by gnome-print\n");
-	gf_pso_sprintf (pso, "8 dict begin");
-	gf_pso_sprintf (pso, "/FontType 3 def\n");
-	gf_pso_sprintf (pso, "/FontMatrix [.001 0 0 .001 0 0] def\n");
-	gf_pso_sprintf (pso, "/FontBBox [0 0 750 950] def\n");
-	gf_pso_sprintf (pso, "/Encoding 256 array def\n");
-	gf_pso_sprintf (pso, "0 1 255 {Encoding exch /.notdef put} for\n");
-	gf_pso_sprintf (pso, "/CharProcs 2 dict def\n");
-	gf_pso_sprintf (pso, "CharProcs begin\n");
-	gf_pso_sprintf (pso, "/.notdef {\n");
-	gf_pso_sprintf (pso, "0 0 moveto 750 0 lineto 750 950 lineto 0 950 lineto closepath\n");
-	gf_pso_sprintf (pso, "50 50 moveto 700 50 lineto 700 900 lineto 50 900 lineto closepath\n");
-	gf_pso_sprintf (pso, "eofill\n");
-	gf_pso_sprintf (pso, "} bind def\n");
-	gf_pso_sprintf (pso, "end\n");
-	gf_pso_sprintf (pso, "/BuildGlyph {\n");
-	gf_pso_sprintf (pso, "1000 0 0 0 750 950 setcachedevice\n");
-	gf_pso_sprintf (pso, "exch /CharProcs get exch\n");
-	gf_pso_sprintf (pso, "2 copy known not {pop /.notdef} if\n");
-	gf_pso_sprintf (pso, "get exec\n");
-	gf_pso_sprintf (pso, "} bind def\n");
-	gf_pso_sprintf (pso, "/BuildChar {1 index /Encoding get exch get\n");
-	gf_pso_sprintf (pso, "1 index /BuildGlyph get exec\n");
-	gf_pso_sprintf (pso, "} bind def\n");
-	gf_pso_sprintf (pso, "currentdict\n");
-	gf_pso_sprintf (pso, "end\n");
-	gf_pso_sprintf (pso, "/%s exch definefont pop\n", pso->encodedname);
-
-	return pso;
-}
-
-static void
-gf_pso_sprintf (GFPSObject * pso, const gchar * format, ...)
-{
-	va_list arguments;
-	gchar *oldlocale;
-	gchar *text;
-	gint len;
-	
-	oldlocale = setlocale (LC_NUMERIC, NULL);
-	setlocale (LC_NUMERIC, "C");
-		
-	va_start (arguments, format);
-	text = g_strdup_vprintf (format, arguments);
-	va_end (arguments);
-
-	len = strlen (text);
-	gf_pso_ensure_space (pso, len);
-	memcpy (pso->buf + pso->length, text, len);
-	pso->length += len;
-	g_free (text);
-
-	setlocale (LC_NUMERIC, oldlocale);
-}
-
-static void
-gf_pso_ensure_space (GFPSObject * pso, gint size)
-{
-	if (pso->length + size > pso->bufsize) {
-		while (pso->length + size > pso->bufsize) pso->bufsize <<= 1;
-		pso->buf = g_renew (guchar, pso->buf, pso->bufsize);
-	}
-}
-
-#endif
