@@ -1,17 +1,6 @@
-#define __GNOME_FONT_C__
-
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- *  Copyright (C) 2000-2001 Ximian Inc. and authors
- *
- *  Authors:
- *    Jody Goldberg <jody@ximian.com>
- *    Miguel de Icaza <miguel@ximian.com>
- *    Lauris Kaplinski <lauris@ximian.com>
- *    Christopher James Lahey <clahey@ximian.com>
- *    Michael Meeks <michael@ximian.com>
- *    Morten Welinder <terra@diku.dk>
- *
- *  GnomeFont - basic user visible handle to scaled typeface
+ *  gnome-font.c: basic user visible handle to scaled typeface
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Library General Public License
@@ -26,15 +15,25 @@
  *  You should have received a copy of the GNU Library General Public
  *  License along with this program; if not, write to the Free Software
  *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *
+ *  Authors:
+ *    Jody Goldberg <jody@ximian.com>
+ *    Miguel de Icaza <miguel@ximian.com>
+ *    Lauris Kaplinski <lauris@ximian.com>
+ *    Christopher James Lahey <clahey@ximian.com>
+ *    Michael Meeks <michael@ximian.com>
+ *    Morten Welinder <terra@diku.dk>
+ *
+ *  Copyright (C) 2000-2001 Ximian Inc. and authors
  */
 
+#define __GNOME_FONT_C__
+
 #include <math.h>
-
 #include <stdlib.h>
-#include <libart_lgpl/art_affine.h>
-
 #include <string.h>
-#include "gnome-font-private.h"
+#include <libart_lgpl/art_affine.h>
+#include <libgnomeprint/gnome-font-private.h>
 
 enum {
 	PROP_0,
@@ -663,38 +662,6 @@ gnome_font_get_pango_description (const GnomeFont *font, gdouble dpi)
 	return desc;
 }
 
-double
-gnome_font_get_width_utf8 (GnomeFont *font, const char *s)
-{
-	g_return_val_if_fail (font != NULL, 0.0);
-	g_return_val_if_fail (GNOME_IS_FONT (font), 0.0);
-	g_return_val_if_fail (s != NULL, 0.0);
- 
-	return gnome_font_get_width_utf8_sized (font, s, strlen (s));
-}
-
-double
-gnome_font_get_width_utf8_sized (GnomeFont *font, const char *text, int n)
-{
-	double width;
-	const gchar *p;
- 
-	g_return_val_if_fail (font != NULL, 0.0);
-	g_return_val_if_fail (GNOME_IS_FONT (font), 0.0);
-	g_return_val_if_fail (text != NULL, 0.0);
-
-	width = 0.0;
-
-	for (p = text; p && p < (text + n); p = g_utf8_next_char (p)) {
-		gint unival, glyph;
-		unival = g_utf8_get_char (p);
-		glyph = gnome_font_lookup_default (font, unival);
-		width += gnome_font_face_get_glyph_width (font->face, glyph);
-	}
-	
-	return width * 0.001 * font->size;
-}
- 
 /* Get the glyph number corresponding to a given unicode, or -1 if it
    is not mapped. */
 gint
@@ -716,4 +683,53 @@ gf_free_outline (gpointer a, gpointer b, gpointer data)
 
 
 
+/**
+ * gnome_font_get_width_utf8:
+ * @font: 
+ * @s: 
+ * 
+ * To be deprecated soon
+ * 
+ * Return Value: 
+ **/
+double
+gnome_font_get_width_utf8 (GnomeFont *font, const char *s)
+{
+	g_return_val_if_fail (font != NULL, 0.0);
+	g_return_val_if_fail (GNOME_IS_FONT (font), 0.0);
+	g_return_val_if_fail (s != NULL, 0.0);
+ 
+	return gnome_font_get_width_utf8_sized (font, s, strlen (s));
+}
 
+/**
+ * gnome_font_get_width_utf8_sized:
+ * @font: 
+ * @text: 
+ * @n: 
+ * 
+ * To be depreacated soon
+ * 
+ * Return Value: 
+ **/
+double
+gnome_font_get_width_utf8_sized (GnomeFont *font, const char *text, int n)
+{
+	double width;
+	const gchar *p;
+ 
+	g_return_val_if_fail (font != NULL, 0.0);
+	g_return_val_if_fail (GNOME_IS_FONT (font), 0.0);
+	g_return_val_if_fail (text != NULL, 0.0);
+
+	width = 0.0;
+
+	for (p = text; p && p < (text + n); p = g_utf8_next_char (p)) {
+		gint unival, glyph;
+		unival = g_utf8_get_char (p);
+		glyph = gnome_font_lookup_default (font, unival);
+		width += gnome_font_face_get_glyph_width (font->face, glyph);
+	}
+	
+	return width * 0.001 * font->size;
+}
