@@ -661,7 +661,7 @@ gpm_parse_config_data (GnomePrintMaster *gpm)
 
 	/* Now the fun part */
 
-	loc = setlocale (LC_NUMERIC, NULL);
+	loc = g_strdup (setlocale (LC_NUMERIC, NULL));
 	setlocale (LC_NUMERIC, "C");
 
 	/* Physical size */
@@ -718,6 +718,7 @@ gpm_parse_config_data (GnomePrintMaster *gpm)
 	}
 
 	setlocale (LC_NUMERIC, loc);
+	g_free (loc);
 }
 
 #define A4_WIDTH (210 * 72 / 25.4)
@@ -800,7 +801,7 @@ gnome_print_config_get_layout_data (GnomePrintConfig *config,
 
 	/* Now the fun part */
 
-	loc = setlocale (LC_NUMERIC, NULL);
+	loc = g_strdup (setlocale (LC_NUMERIC, NULL));
 	setlocale (LC_NUMERIC, "C");
 
 	/* Physical size */
@@ -862,6 +863,7 @@ gnome_print_config_get_layout_data (GnomePrintConfig *config,
 	g_return_val_if_fail (num_pages > 0, NULL);
 
 	setlocale (LC_NUMERIC, loc);
+	g_free (loc);
 
 	/* Success */
 
@@ -1098,7 +1100,7 @@ gnome_print_config_get_transform (GnomePrintConfig *config, const guchar *key, g
 	if (!v)
 		return FALSE;
 
-	loc = setlocale (LC_NUMERIC, NULL);
+	loc = g_strdup (setlocale (LC_NUMERIC, NULL));
 	setlocale (LC_NUMERIC, "C");
 
 	ret = gpm_parse_transform (v, t);
@@ -1108,6 +1110,7 @@ gnome_print_config_get_transform (GnomePrintConfig *config, const guchar *key, g
 	}
 
 	setlocale (LC_NUMERIC, loc);
+	g_free (loc);
 
 	return ret;
 }
