@@ -188,7 +188,7 @@ gnome_print_transport_printf (GnomePrintTransport *transport, const char *format
 	g_return_val_if_fail (format != NULL, GNOME_PRINT_ERROR_UNKNOWN);
 	g_return_val_if_fail (transport->opened, GNOME_PRINT_ERROR_UNKNOWN);
 
-	loc = setlocale (LC_NUMERIC, NULL);
+	loc = g_strdup (setlocale (LC_NUMERIC, NULL));
 	setlocale (LC_NUMERIC, "C");
 
 	va_start (arguments, format);
@@ -202,6 +202,7 @@ gnome_print_transport_printf (GnomePrintTransport *transport, const char *format
 	g_free (buf);
 
 	setlocale (LC_NUMERIC, loc);
+	g_free (loc);
 
 	return ret;
 }
