@@ -23,8 +23,6 @@
  *
  */
 
-#define _GP_FONTMAP_C_
-
 /* TODO: Recycle font entries, if they are identical for different maps */
 
 #include <sys/types.h>
@@ -474,7 +472,7 @@ gp_fm_load_font_2_0_type1 (GPFontMap *map, xmlNodePtr node)
 
 	gp_font_entry_2_0_load_data (e, node);
 	gp_font_entry_2_0_type1_load_files (t1, node);
-	if (!e->familyname || !e->psname || !t1->pfb.name) {
+	if (!e->familyname || !e->psname || !t1->pfb.name || !g_file_test (t1->pfb.name, G_FILE_TEST_EXISTS)) {
 		gp_font_entry_unref (e);
 		return;
 	}
@@ -537,7 +535,7 @@ gp_fm_load_font_2_0_type1alias (GPFontMap *map, xmlNodePtr node)
 
 	gp_font_entry_2_0_load_data (e, node);
 	gp_font_entry_2_0_type1_load_files (t1, node);
-	if (!e->familyname || !e->psname || !t1->pfb.name) {
+	if (!e->familyname || !e->psname || !t1->pfb.name || !g_file_test (t1->pfb.name, G_FILE_TEST_EXISTS)) {
 		gp_font_entry_unref (e);
 		return;
 	}
@@ -590,7 +588,7 @@ gp_fm_load_font_2_0_truetype (GPFontMap *map, xmlNodePtr node)
 
 	gp_font_entry_2_0_load_data (e, node);
 	gp_font_entry_2_0_truetype_load_files (tt, node);
-	if (!e->familyname || !e->psname || !tt->ttf.name) {
+	if (!e->familyname || !e->psname || !tt->ttf.name || !g_file_test (tt->ttf.name, G_FILE_TEST_EXISTS)) {
 		gp_font_entry_unref (e);
 		return;
 	}
