@@ -160,7 +160,8 @@ gpa_option_duplicate (GPANode *node)
 	for (child = option->children; child != NULL; child = child->next) {
 		GPANode *newchild;
 		newchild = gpa_node_duplicate (child);
-		if (newchild) l = g_slist_prepend (l, newchild);
+		if (newchild)
+			l = g_slist_prepend (l, newchild);
 	}
 
 	while (l) {
@@ -184,61 +185,86 @@ gpa_option_verify (GPANode *node)
 	option = GPA_OPTION (node);
 
 	/* Each option has to have Id */
-	if (!GPA_NODE_ID_EXISTS (node)) return FALSE;
+	if (!GPA_NODE_ID_EXISTS (node))
+		return FALSE;
 
 	switch (option->type) {
 	case GPA_OPTION_TYPE_NODE:
 		/* !Name, !Value, children */
-		if (option->name) return FALSE;
-		if (option->value) return FALSE;
-		if (!option->children) return FALSE;
+		if (option->name)
+			return FALSE;
+		if (option->value)
+			return FALSE;
+		if (!option->children)
+			return FALSE;
 		for (child = option->children; child != NULL; child = child->next) {
-			if (!GPA_IS_OPTION (child)) return FALSE;
-			if (!gpa_node_verify (child)) return FALSE;
+			if (!GPA_IS_OPTION (child))
+				return FALSE;
+			if (!gpa_node_verify (child))
+				return FALSE;
 		}
 		break;
 	case GPA_OPTION_TYPE_KEY:
 		/* !Name, Value || children */
-		if (option->name) return FALSE;
-		if (!option->value && !option->children) return FALSE;
+		if (option->name)
+			return FALSE;
+		if (!option->value && !option->children)
+			return FALSE;
 		for (child = option->children; child != NULL; child = child->next) {
-			if (!GPA_IS_OPTION (child)) return FALSE;
-			if (GPA_OPTION (child)->type != GPA_OPTION_TYPE_KEY) return FALSE;
-			if (!gpa_node_verify (child)) return FALSE;
+			if (!GPA_IS_OPTION (child))
+				return FALSE;
+			if (GPA_OPTION (child)->type != GPA_OPTION_TYPE_KEY)
+				return FALSE;
+			if (!gpa_node_verify (child))
+				return FALSE;
 		}
 		break;
 	case GPA_OPTION_TYPE_LIST:
 		/* List should not have name */
-		if (option->name) return FALSE;
+		if (option->name)
+			return FALSE;
 		/* List has to have default value */
-		if (!option->value) return FALSE;
+		if (!option->value)
+			return FALSE;
 		/* List has to have children of type item */
-		if (!option->children) return FALSE;
+		if (!option->children)
+			return FALSE;
 		for (child = option->children; child != NULL; child = child->next) {
-			if (!GPA_IS_OPTION (child)) return FALSE;
-			if (GPA_OPTION (child)->type != GPA_OPTION_TYPE_ITEM) return FALSE;
-			if (!gpa_node_verify (child)) return FALSE;
+			if (!GPA_IS_OPTION (child))
+				return FALSE;
+			if (GPA_OPTION (child)->type != GPA_OPTION_TYPE_ITEM)
+				return FALSE;
+			if (!gpa_node_verify (child))
+				return FALSE;
 		}
 		break;
 	case GPA_OPTION_TYPE_ITEM:
 		/* Item has to have name */
-		if (!option->name) return FALSE;
-		if (!gpa_node_verify (option->name)) return FALSE;
+		if (!option->name)
+			return FALSE;
+		if (!gpa_node_verify (option->name))
+			return FALSE;
 		/* Item should not have value */
-		if (option->value) return FALSE;
+		if (option->value)
+			return FALSE;
 		/* Item may have children */
 		for (child = option->children; child != NULL; child = child->next) {
-			if (!GPA_IS_OPTION (child)) return FALSE;
-			if (!gpa_node_verify (child)) return FALSE;
+			if (!GPA_IS_OPTION (child))
+				return FALSE;
+			if (!gpa_node_verify (child))
+				return FALSE;
 		}
 		break;
 	case GPA_OPTION_TYPE_STRING:
 		/* String should not have name */
-		if (option->name) return FALSE;
+		if (option->name)
+			return FALSE;
 		/* String should have value */
-		if (!option->value) return FALSE;
+		if (!option->value)
+			return FALSE;
 		/* String should not have children */
-		if (option->children) return FALSE;
+		if (option->children)
+			return FALSE;
 		break;
 	default:
 		return FALSE;
@@ -253,8 +279,10 @@ gpa_option_get_value (GPANode *node)
 
 	option = GPA_OPTION (node);
 
-	if (option->value) return g_strdup (option->value);
-	if (GPA_NODE_ID_EXISTS (node)) return g_strdup (GPA_NODE_ID (node));
+	if (option->value)
+		return g_strdup (option->value);
+	if (GPA_NODE_ID_EXISTS (node))
+		return g_strdup (GPA_NODE_ID (node));
 
 	return NULL;
 }
@@ -267,11 +295,13 @@ gpa_option_get_child (GPANode *node, GPANode *ref)
 	option = GPA_OPTION (node);
 
 	if (!ref) {
-		if (option->children) gpa_node_ref (option->children);
+		if (option->children)
+			gpa_node_ref (option->children);
 		return option->children;
 	}
 
-	if (ref->next) gpa_node_ref (ref->next);
+	if (ref->next)
+		gpa_node_ref (ref->next);
 
 	return ref->next;
 }
@@ -287,7 +317,8 @@ gpa_option_lookup (GPANode *node, const guchar *path)
 	option = GPA_OPTION (node);
 
 	if (!strncmp (path, "Name", 4)) {
-		if (!option->name) return NULL;
+		if (!option->name)
+			return NULL;
 		if (!path[4]) {
 			gpa_node_ref (GPA_NODE (option->name));
 			return GPA_NODE (option->name);
@@ -364,7 +395,8 @@ gpa_option_create_key_private (GPAOption *option)
 		key = (GPAKey *) gpa_node_new (GPA_TYPE_KEY, GPA_NODE_ID (option));
 		key->option = GPA_NODE (option);
 		gpa_node_ref (key->option);
-		if (option->value) key->value = g_strdup (option->value);
+		if (option->value)
+			key->value = g_strdup (option->value);
 		l = NULL;
 		for (child = option->children; child != NULL; child = child->next) {
 			GPANode *kch;
@@ -394,7 +426,8 @@ gpa_option_create_key_private (GPAOption *option)
 			for (ich = GPA_OPTION (child)->children; ich != NULL; ich = ich->next) {
 				GPANode *kch;
 				kch = gpa_option_create_key (GPA_OPTION (ich));
-				if (kch) l = g_slist_prepend (l, kch);
+				if (kch)
+					l = g_slist_prepend (l, kch);
 			}
 			while (l) {
 				GPANode *kch;
@@ -597,12 +630,16 @@ gpa_option_new_list_from_tree (xmlNodePtr tree, const guchar *id)
 				cho = gpa_option_new_from_tree (xmlc);
 				if (cho) {
 					l = g_slist_prepend (l, cho);
-					if (GPA_NODE_ID_COMPARE (cho, xmldef)) has_default = TRUE;
+					if (GPA_NODE_ID_COMPARE (cho, xmldef))
+						has_default = TRUE;
 				}
 			} else if (!strcmp (xmlc->name, "Fill")) {
 				xmlval = xmlGetProp (xmlc, "Ref");
 				if (xmlval) {
 					GPANode *def, *ref;
+#ifdef __GNUC__	
+#warning FIXME: This seems broken because this function is called when gpa_defaults is called so we recurse into here					
+#endif	
 					def = gpa_defaults ();
 					ref = gpa_node_get_path_node (def, xmlval);
 					gpa_node_unref (def);
@@ -613,10 +650,12 @@ gpa_option_new_list_from_tree (xmlNodePtr tree, const guchar *id)
 							GPANode *new;
 							new = gpa_node_duplicate (lc);
 							l = g_slist_prepend (l, new);
-							if (GPA_NODE_ID_COMPARE (new, xmldef)) has_default = TRUE;
+							if (GPA_NODE_ID_COMPARE (new, xmldef))
+								has_default = TRUE;
 						}
 					}
-					if (ref) gpa_node_unref (ref);
+					if (ref)
+						gpa_node_unref (ref);
 				}
 			} else {
 				g_warning ("Invalid list child in option tree %s", xmlc->name);
@@ -684,7 +723,8 @@ gpa_option_new_item_from_tree (xmlNodePtr tree, const guchar *id)
 			if (!strcmp (xmlc->name, "Option") || !strcmp (xmlc->name, "Key")) {
 				GPANode *cho;
 				cho = gpa_option_new_from_tree (xmlc);
-				if (cho) l = g_slist_prepend (l, cho);
+				if (cho)
+					l = g_slist_prepend (l, cho);
 			} else if (strcmp (xmlc->name, "Name")) {
 				g_warning ("Invalid tag in option tree %s", xmlc->name);
 			}
@@ -746,7 +786,8 @@ gpa_option_list_new_from_tree (xmlNodePtr tree)
 		if (!strcmp (xmlc->name, "Option") || !strcmp (xmlc->name, "Item") || !strcmp (xmlc->name, "Key")) {
 			GPANode *option;
 			option = gpa_option_new_from_tree (xmlc);
-			if (option) l = g_slist_prepend (l, option);
+			if (option)
+				l = g_slist_prepend (l, option);
 		}
 	}
 
@@ -878,7 +919,8 @@ gpa_option_key_new (const guchar *id, const guchar *value)
 
 	option = (GPAOption *) gpa_node_new (GPA_TYPE_OPTION, id);
 	option->type = GPA_OPTION_TYPE_KEY;
-	if (value) option->value = g_strdup (value);
+	if (value)
+		option->value = g_strdup (value);
 
 	return (GPANode *) option;
 }
