@@ -28,6 +28,7 @@
 #define noGPA_PRINTER_DEBUG
 
 #include <string.h>
+#include <sys/types.h>
 #include <dirent.h> /* For the DIR structure stuff */
 #include <libxml/xmlmemory.h>
 #include <libxml/parser.h>
@@ -132,14 +133,20 @@ gpa_printer_verify (GPANode *node)
 
 	printer = GPA_PRINTER (node);
 
-	if (GPA_NODE_ID_EXISTS (node)) return FALSE;
-
-	if (!printer->name) return FALSE;
-	if (!gpa_node_verify (printer->name)) return FALSE;
-	if (!printer->settings) return FALSE;
-	if (!gpa_node_verify (GPA_NODE (printer->settings))) return FALSE;
-	if (!printer->model) return FALSE;
-	if (!gpa_node_verify (printer->model)) return FALSE;
+	if (GPA_NODE_ID_EXISTS (node))
+		return FALSE;
+	if (!printer->name)
+		return FALSE;
+	if (!gpa_node_verify (printer->name))
+		return FALSE;
+	if (!printer->settings)
+		return FALSE;
+	if (!gpa_node_verify (GPA_NODE (printer->settings)))
+		return FALSE;
+	if (!printer->model)
+		return FALSE;
+	if (!gpa_node_verify (printer->model))
+		return FALSE;
 
 	return TRUE;
 }
@@ -151,7 +158,8 @@ gpa_printer_get_value (GPANode *node)
 
 	printer = GPA_PRINTER (node);
 
-	if (GPA_NODE_ID_EXISTS (node)) return g_strdup (GPA_NODE_ID (node));
+	if (GPA_NODE_ID_EXISTS (node))
+		return g_strdup (GPA_NODE_ID (node));
 
 	return NULL;
 }
@@ -177,7 +185,8 @@ gpa_printer_get_child (GPANode *node, GPANode *ref)
 		child = printer->model;
 	}
 
-	if (child) gpa_node_ref (child);
+	if (child)
+		gpa_node_ref (child);
 
 	return child;
 }
@@ -192,9 +201,12 @@ gpa_printer_lookup (GPANode *node, const guchar *path)
 
 	child = NULL;
 
-	if (gpa_node_lookup_ref (&child, GPA_NODE (printer->name), path, "Name")) return child;
-	if (gpa_node_lookup_ref (&child, GPA_NODE (printer->settings), path, "Settings")) return child;
-	if (gpa_node_lookup_ref (&child, GPA_NODE (printer->model), path, "Model")) return child;
+	if (gpa_node_lookup_ref (&child, GPA_NODE (printer->name), path, "Name"))
+		return child;
+	if (gpa_node_lookup_ref (&child, GPA_NODE (printer->settings), path, "Settings"))
+		return child;
+	if (gpa_node_lookup_ref (&child, GPA_NODE (printer->model), path, "Model"))
+		return child;
 
 	return NULL;
 }
@@ -253,7 +265,8 @@ gpa_printer_new_from_tree (xmlNodePtr tree)
 	}
 	xmlFree (xmlver);
 
-	if (!namedict) namedict = g_hash_table_new (g_str_hash, g_str_equal);
+	if (!namedict)
+		namedict = g_hash_table_new (g_str_hash, g_str_equal);
 
 	printer = NULL;
 	name = NULL;
@@ -314,14 +327,17 @@ gpa_printer_new_from_tree (xmlNodePtr tree)
 			printer->settings->children = settings;
 		}
 		/* fixme: */
-		if (printer->settings->children) gpa_list_set_default (printer->settings, printer->settings->children);
+		if (printer->settings->children)
+			gpa_list_set_default (printer->settings, printer->settings->children);
 		/* Model */
 		printer->model = gpa_reference_new (model);
 		printer->model->parent = GPA_NODE (printer);
 		gpa_node_unref (GPA_NODE (model));
 	} else {
-		if (name) gpa_node_unref (name);
-		if (model) gpa_node_unref (model);
+		if (name)
+			gpa_node_unref (name);
+		if (model)
+			gpa_node_unref (model);
 		while (l) {
 			gpa_node_unref (GPA_NODE (l->data));
 			l = g_slist_remove (l, l->data);
@@ -341,7 +357,8 @@ gpa_printer_new_from_file (const gchar *filename)
 	xmlNodePtr root;
 
 	doc = xmlParseFile (filename);
-	if (!doc) return NULL;
+	if (!doc)
+		return NULL;
 	root = doc->xmlRootNode;
 	printer = NULL;
 	if (!strcmp (root->name, "Printer")) {
@@ -372,7 +389,9 @@ gpa_printer_list_load (void)
 {
 	gchar *dirname;
 
-	if (printers) return (GPAList *) gpa_node_ref (GPA_NODE (printers));
+	if (printers) {
+		return (GPAList *) gpa_node_ref (GPA_NODE (printers));
+	}
 
 	printers = GPA_LIST (gpa_node_new (GPA_TYPE_LIST, "Printers"));
 	gpa_list_construct (GPA_LIST (printers), GPA_TYPE_PRINTER, TRUE);
@@ -401,7 +420,8 @@ gpa_printer_list_load_from_dir (GPAList *printers, const gchar *dirname)
 	GSList *l;
 
 	dir = opendir (dirname);
-	if (!dir) return;
+	if (!dir)
+		return;
 
 	l = NULL;
 	iddict = g_hash_table_new (g_str_hash, g_str_equal);
@@ -410,8 +430,10 @@ gpa_printer_list_load_from_dir (GPAList *printers, const gchar *dirname)
 		gchar *filename;
 		GPANode *printer;
 		len = strlen (dent->d_name);
-		if (len < 9) continue;
-		if (strcmp (dent->d_name + len - 8, ".printer")) continue;
+		if (len < 9)
+			continue;
+		if (strcmp (dent->d_name + len - 8, ".printer"))
+			continue;
 		filename = g_strdup_printf ("%s/%s", dirname, dent->d_name);
 		printer = gpa_printer_new_from_file (filename);
 		g_free (filename);
@@ -455,7 +477,8 @@ gpa_printer_get_default (void)
 		def = printers->children;
 	}
 
-	if (def) gpa_node_ref (def);
+	if (def)
+		gpa_node_ref (def);
 
 	gpa_node_unref (gpa_node_cache (GPA_NODE (printers)));
 
@@ -468,11 +491,6 @@ gpa_printer_get_by_id (const guchar *id)
 	GPAList *printers;
 	GPANode *child;
 
-#ifdef __GNUC__
-#warning FIXME: We always return NULL, return NULL but don't leak'. Chema, 10-May-02. 
-#endif
-	return NULL;
-	
 	g_return_val_if_fail (id != NULL, NULL);
 	g_return_val_if_fail (*id != '\0', NULL);
 
@@ -483,15 +501,17 @@ gpa_printer_get_by_id (const guchar *id)
 	if (printers) {
 		for (child = printers->children; child != NULL; child = child->next) {
 			g_assert (GPA_IS_PRINTER (child));
-			if (GPA_NODE_ID_COMPARE (child, id)) break;
+			if (GPA_NODE_ID_COMPARE (child, id))
+				break;
 		}
 	}
 
-	if (child) gpa_node_ref (child);
+	if (child)
+		gpa_node_ref (child);
 
 	gpa_node_unref (gpa_node_cache (GPA_NODE (printers)));
 
-	return NULL;
+	return child;
 }
 
 GPANode *
@@ -524,7 +544,8 @@ gpa_printer_new_from_model (GPAModel *model, const guchar *name)
 	g_return_val_if_fail (name != NULL, NULL);
 	g_return_val_if_fail (*name != '\0', NULL);
 
-	if (!namedict) namedict = g_hash_table_new (g_str_hash, g_str_equal);
+	if (!namedict)
+		namedict = g_hash_table_new (g_str_hash, g_str_equal);
 #if 0
 	g_return_val_if_fail (!g_hash_table_lookup (namedict, name), NULL);
 #endif
@@ -584,7 +605,8 @@ gpa_printer_save (GPAPrinter *printer)
 
 	for (child = printer->settings->children; child != NULL; child = child->next) {
 		xmln = gpa_settings_write (doc, child);
-		if (xmln) xmlAddChild (root, xmln);
+		if (xmln)
+			xmlAddChild (root, xmln);
 	}
 
 	filename = g_strdup_printf ("%s/.gnome/printers/%s.printer", g_get_home_dir (), GPA_NODE_ID (printer));
